# pin-and-string: A python module to evaluate and manupilate shapes that can be built by pins and string.

*pin-and-string* is a **Python** package that provides functions and built-in matrices for constructing and manupilating shapes that can be built by pins and string.